tsseg.algorithms.bocd package
=============================

Offline Bayesian change-point inference using a conjugate Normal-Gamma prior,
dynamic programming, and posterior thresholding.

| **Type:** change point detection
| **Supervision:** unsupervised or semi-supervised
| **Scope:** univariate and multivariate

**Implementation:** Adapted from hildensia/bayesian_changepoint_detection. Apache
License 2.0.

**References:** Fearnhead (2006), Statistics and Computing; Adams & MacKay (2007),
arXiv.

Submodules
----------

tsseg.algorithms.bocd.bayesian\_models module
---------------------------------------------

.. automodule:: tsseg.algorithms.bocd.bayesian_models
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.bocd.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.bocd.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.bocd
   :members:
   :show-inheritance:
   :undoc-members:
